@@ -1,6 +1,7 @@
 import datetime as dt
 import errno
 import functools
+import getpass
 import glob
 import io
 import json
@@ -25,6 +26,18 @@ from selenium.common.exceptions import (
 
 from .google_drive_helpers import GoogleDriveHelper
 
+LIGHT_COLORMAP = [
+    (0.533, 0.741, 0.902),
+    (0.984, 0.698, 0.345),
+    (0.565, 0.804, 0.592),
+    (0.965, 0.667, 0.788),
+    (0.749, 0.647, 0.329),
+    (0.737, 0.6, 0.78),
+    (0.929, 0.867, 0.275),
+    (0.941, 0.494, 0.431),
+    (0.549, 0.549, 0.549),
+]
+
 # Natural gas emission factor
 # 119.58 lbs CO2/1000 cubic feet of natural gas
 # 1.915 kg CO2/1 m^3 natural gas [119.58 lbs * (1 kg / 2.204623 lbs) *
@@ -155,10 +168,6 @@ def is_gdrive_path(path):
         return False
 
 
-class Timeout(Exception):
-    pass
-
-
 def wait_for_element(func, seconds=5, *args, **kwargs):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
@@ -194,10 +203,6 @@ def install_colab_dependencies(required_envs, debug=False):
             output += _run_cmd(f"apt-get update")
             output += _run_cmd(f"apt install chromium-chromedriver")
 
-        # Force a version of pandas that is compatible with colab
-        if _run_cmd("python -c 'import pandas; print(pandas.__version__)'") != "1.1.5":
-            output += _run_cmd(f"{ sys.executable } -m pip install pandas==1.1.5")
-
         if debug:
             print(output)
 
@@ -220,7 +225,10 @@ def install_colab_dependencies(required_envs, debug=False):
 
             if not os.getenv(env_name):
                 print(f"Enter a value for { env_name }")
-                value = input()
+                if "PASSWORD" in env_name.upper():
+                    value = getpass.getpass()
+                else:
+                    value = input()
                 with open(dot_env_path, "a") as f:
                     f.write(f"{ env_name }={ value }\n")
                 os.environ[env_name] = value
@@ -243,6 +251,10 @@ def wait_for_permission(func, seconds=5, *args, **kwargs):
     return wrapper
 
 
+class Timeout(Exception):
+    pass
+
+
 class UnsupportedFileType(Exception):
     pass
 
@@ -260,7 +272,7 @@ class UtilityAPI:
         file_ext=".csv",
         headless=True,
         browser="Firefox",
-        timeout=10,
+        timeout=30,
         save_statements=True,
         google_sa_credentials=None,
     ):
@@ -312,19 +324,29 @@ class UtilityAPI:
             except IndexError:  # Folder doesn't exist
                 utility_folder = self._gdh.create_subfolder(folder_id, self.name)
 
-            try:
-                data_file = self._gdh.get_file_in_folder(
-                    utility_folder["id"], "monthly" + self._file_ext
-                )
-                file = self._gdh.download_file(
-                    data_file["id"],
-                    os.path.join(self._temp_download_dir, "monthly" + self._file_ext),
-                )
-                self._monthly_history = pd.read_csv(
-                    os.path.join(self._temp_download_dir, "monthly" + self._file_ext)
-                ).set_index("Date")
-            except IndexError:  # File doesn't exist
-                self._monthly_history = pd.DataFrame()
+            def get_history_file(resolution, index_col):
+                try:
+                    data_file = self._gdh.get_file_in_folder(
+                        utility_folder["id"], resolution + self._file_ext
+                    )
+                    file = self._gdh.download_file(
+                        data_file["id"],
+                        os.path.join(
+                            self._temp_download_dir, resolution + self._file_ext
+                        ),
+                    )
+                    return pd.read_csv(
+                        os.path.join(
+                            self._temp_download_dir, resolution + self._file_ext
+                        )
+                    ).set_index(index_col)
+                except IndexError:  # File doesn't exist
+                    return pd.DataFrame()
+
+            self._monthly_history = get_history_file("monthly", "Date")
+            hourly_history = get_history_file("hourly", "Datetime")
+            if len(hourly_history):
+                self._hourly_history = hourly_history
 
         elif os.path.exists(
             os.path.join(self._data_path, self.name, "monthly" + self._file_ext)
@@ -334,6 +356,17 @@ class UtilityAPI:
                 os.path.join(self._data_path, self.name, "monthly" + self._file_ext)
             ).set_index("Date")
 
+            if os.path.exists(
+                os.path.join(self._data_path, self.name, "hourly" + self._file_ext)
+            ):
+                self._hourly_history = pd.read_csv(
+                    os.path.join(self._data_path, self.name, "hourly" + self._file_ext)
+                ).set_index("Datetime")
+
+        self._monthly_history.index = pd.to_datetime(self._monthly_history.index)
+        if hasattr(self, "_hourly_history"):
+            self._hourly_history.index = pd.to_datetime(self._hourly_history.index)
+
     def _init_driver(self):
         if self._browser == "Chrome":
             options = webdriver.ChromeOptions()
@@ -380,7 +413,6 @@ class UtilityAPI:
                 "resolution must be one of: "
                 + f"{ ', '.join(self._resolutions_available) }."
             )
-
         if resolution == "monthly":
             return self._monthly_history
         elif resolution == "hourly":
@@ -521,13 +553,14 @@ class UtilityAPI:
                     traceback.print_exc()
         self._monthly_history = self._monthly_history.append(df_new_rows)
         self._monthly_history.sort_index(inplace=True)
+        self._monthly_history.index = pd.to_datetime(self._monthly_history.index)
         self._update_history()
         return df_new_rows
 
     def _update_history(self):
         # Update history
 
-        # If `data_path` is a google drive folder, upload the monthly data file.
+        # If `data_path` is a google drive folder, upload the history file(s).
         if is_gdrive_path(self._data_path):
             folder_id = self._data_path.split("/")[-1]
             try:
@@ -535,24 +568,35 @@ class UtilityAPI:
             except IndexError:
                 utility_folder = self._gdh.create_subfolder(folder_id, self.name)
 
+            def upload_file(resolution):
+                try:
+                    data_file = self._gdh.get_file_in_folder(
+                        utility_folder["id"], resolution + self._file_ext
+                    )
+                    self._gdh.upload_file(
+                        data_file["id"],
+                        os.path.join(
+                            self._temp_download_dir, resolution + self._file_ext
+                        ),
+                    )
+                except IndexError:
+                    data_file = self._gdh.create_file_in_folder(
+                        utility_folder["id"],
+                        os.path.join(
+                            self._temp_download_dir, resolution + self._file_ext
+                        ),
+                    )
+
             self._monthly_history.to_csv(
                 os.path.join(self._temp_download_dir, "monthly" + self._file_ext)
             )
+            upload_file("monthly")
 
-            try:
-                data_file = self._gdh.get_file_in_folder(
-                    utility_folder["id"], "monthly" + self._file_ext
+            if hasattr(self, "_hourly_history"):
+                self._hourly_history.to_csv(
+                    os.path.join(self._temp_download_dir, "hourly" + self._file_ext)
                 )
-                self._gdh.upload_file(
-                    data_file["id"],
-                    os.path.join(self._temp_download_dir, "monthly" + self._file_ext),
-                )
-            except IndexError:
-                data_file = self._gdh.create_file_in_folder(
-                    utility_folder["id"],
-                    os.path.join(self._temp_download_dir, "monthly" + self._file_ext),
-                )
-
+                upload_file("hourly")
         else:
             # Create directories if necessary
             os.makedirs(os.path.join(self._data_path, self.name), exist_ok=True)
@@ -561,3 +605,8 @@ class UtilityAPI:
             self._monthly_history.to_csv(
                 os.path.join(self._data_path, self.name, "monthly" + self._file_ext)
             )
+
+            if hasattr(self, "_hourly_history"):
+                self._hourly_history.to_csv(
+                    os.path.join(self._data_path, self.name, "hourly" + self._file_ext)
+                )
